
-------------------------------------------------------------------
-- System Generator version 7.1.01 VHDL source file.
--
-- Copyright(C) 2005 by Xilinx, Inc.  All rights reserved.  This
-- text/file contains proprietary, confidential information of Xilinx,
-- Inc., is distributed under license from Xilinx, Inc., and may be used,
-- copied and/or disclosed only pursuant to the terms of a valid license
-- agreement with Xilinx, Inc.  Xilinx hereby grants you a license to use
-- this text/file solely for design, simulation, implementation and
-- creation of design files limited to Xilinx devices or technologies.
-- Use with non-Xilinx devices or technologies is expressly prohibited
-- and immediately terminates your license unless covered by a separate
-- agreement.
--
-- Xilinx is providing this design, code, or information "as is" solely
-- for use in developing programs and solutions for Xilinx devices.  By
-- providing this design, code, or information as one possible
-- implementation of this feature, application or standard, Xilinx is
-- making no representation that this implementation is free from any
-- claims of infringement.  You are responsible for obtaining any rights
-- you may require for your implementation.  Xilinx expressly disclaims
-- any warranty whatsoever with respect to the adequacy of the
-- implementation, including but not limited to warranties of
-- merchantability or fitness for a particular purpose.
--
-- Xilinx products are not intended for use in life support appliances,
-- devices, or systems.  Use in such applications is expressly prohibited.
--
-- Any modifications that are made to the source code are done at the user's
-- sole risk and will be unsupported.
--
-- This copyright and support notice must be retained as part of this
-- text at all times.  (c) Copyright 1995-2005 Xilinx, Inc.  All rights
-- reserved.
-------------------------------------------------------------------
library IEEE;
use IEEE.std_logic_1164.all;
use work.conv_pkg.all;
-- synopsys translate_off
library unisim;
use unisim.vcomponents.all;
-- synopsys translate_on
entity srl17e is
    generic (width : integer:=16;
             latency : integer :=8);
    port (clk   : in std_logic;
          ce    : in std_logic;
          d     : in std_logic_vector(width-1 downto 0);
          q     : out std_logic_vector(width-1 downto 0));
end srl17e;
architecture structural of srl17e is
    component SRL16E
        port (D   : in STD_ULOGIC;
              CE  : in STD_ULOGIC;
              CLK : in STD_ULOGIC;
              A0  : in STD_ULOGIC;
              A1  : in STD_ULOGIC;
              A2  : in STD_ULOGIC;
              A3  : in STD_ULOGIC;
              Q   : out STD_ULOGIC);
    end component;
    attribute syn_black_box of SRL16E : component is true;
    attribute fpga_dont_touch of SRL16E : component is "true";
    component FDE
        port(
            Q  :        out   STD_ULOGIC;
            D  :        in    STD_ULOGIC;
            C  :        in    STD_ULOGIC;
            CE :        in    STD_ULOGIC);
    end component;
    attribute syn_black_box of FDE : component is true;
    attribute fpga_dont_touch of FDE : component is "true";
    constant a : std_logic_vector(4 downto 0) :=
        integer_to_std_logic_vector(latency-2,5,xlSigned);
    signal d_delayed : std_logic_vector(width-1 downto 0);
    signal srl16_out : std_logic_vector(width-1 downto 0);
begin
    d_delayed <= d after 200 ps;
    reg_array : for i in 0 to width-1 generate
        srl16_used: if latency > 1 generate
            u1 : srl16e port map(clk => clk,
                                 d => d_delayed(i),
                                 q => srl16_out(i),
                                 ce => ce,
                                 a0 => a(0),
                                 a1 => a(1),
                                 a2 => a(2),
                                 a3 => a(3));
        end generate;
        srl16_not_used: if latency <= 1 generate
            srl16_out(i) <= d_delayed(i);
        end generate;
        fde_used: if latency /= 0  generate
            u2 : fde port map(c => clk,
                              d => srl16_out(i),
                              q => q(i),
                              ce => ce);
        end generate;
        fde_not_used: if latency = 0  generate
            q(i) <= srl16_out(i);
        end generate;
    end generate;
 end structural;
library IEEE;
use IEEE.std_logic_1164.all;
use work.conv_pkg.all;
entity synth_reg is
    generic (width           : integer := 8;
             latency         : integer := 1);
    port (i       : in std_logic_vector(width-1 downto 0);
          ce      : in std_logic;
          clr     : in std_logic;
          clk     : in std_logic;
          o       : out std_logic_vector(width-1 downto 0));
end synth_reg;
architecture structural of synth_reg is
    component srl17e
        generic (width : integer:=16;
                 latency : integer :=8);
        port (clk : in std_logic;
              ce  : in std_logic;
              d   : in std_logic_vector(width-1 downto 0);
              q   : out std_logic_vector(width-1 downto 0));
    end component;
    function calc_num_srl17es (latency : integer)
        return integer
    is
        variable remaining_latency : integer;
        variable result : integer;
    begin
        result := latency / 17;
        remaining_latency := latency - (result * 17);
        if (remaining_latency /= 0) then
            result := result + 1;
        end if;
        return result;
    end;
    constant complete_num_srl17es : integer := latency / 17;
    constant num_srl17es : integer := calc_num_srl17es(latency);
    constant remaining_latency : integer := latency - (complete_num_srl17es * 17);
    type register_array is array (num_srl17es downto 0) of
        std_logic_vector(width-1 downto 0);
    signal z : register_array;
begin
    z(0) <= i;
    complete_ones : if complete_num_srl17es > 0 generate
        srl17e_array: for i in 0 to complete_num_srl17es-1 generate
            delay_comp : srl17e
                generic map (width => width,
                             latency => 17)
                port map (clk => clk,
                          ce  => ce,
                          d       => z(i),
                          q       => z(i+1));
        end generate;
    end generate;
    partial_one : if remaining_latency > 0 generate
        last_srl17e : srl17e
            generic map (width => width,
                         latency => remaining_latency)
            port map (clk => clk,
                      ce  => ce,
                      d   => z(num_srl17es-1),
                      q   => z(num_srl17es));
    end generate;
    o <= z(num_srl17es);
end structural;
library IEEE;
use IEEE.std_logic_1164.all;
use work.conv_pkg.all;
entity synth_reg_reg is
    generic (width           : integer := 8;
             latency         : integer := 1);
    port (i       : in std_logic_vector(width-1 downto 0);
          ce      : in std_logic;
          clr     : in std_logic;
          clk     : in std_logic;
          o       : out std_logic_vector(width-1 downto 0));
end synth_reg_reg;
architecture behav of synth_reg_reg is
  type reg_array_type is array (latency-1 downto 0) of std_logic_vector(width -1 downto 0);
  signal reg_bank : reg_array_type := (others => (others => '0'));
  signal reg_bank_in : reg_array_type := (others => (others => '0'));
  attribute syn_allow_retiming : boolean;
  attribute syn_srlstyle : string;
  attribute syn_allow_retiming of reg_bank : signal is true;
  attribute syn_allow_retiming of reg_bank_in : signal is true;
  attribute syn_srlstyle of reg_bank : signal is "registers";
  attribute syn_srlstyle of reg_bank_in : signal is "registers";
begin
  latency_eq_0: if latency = 0 generate
    o <= i;
  end generate latency_eq_0;
  latency_gt_0: if latency >= 1 generate
    o <= reg_bank(latency-1);
    reg_bank_in(0) <= i;
    loop_gen: for idx in latency-2 downto 0 generate
      reg_bank_in(idx+1) <= reg_bank(idx);
    end generate loop_gen;
    sync_loop: for sync_idx in latency-1 downto 0 generate
      sync_proc: process (clk)
      begin
        if clk'event and clk = '1' then
          if ce = '1'  then
            reg_bank(sync_idx) <= reg_bank_in(sync_idx);
          end if;
        end if;
      end process sync_proc;
    end generate sync_loop;
  end generate latency_gt_0;
end behav;


-------------------------------------------------------------------
-- System Generator version 7.1.01 VHDL source file.
--
-- Copyright(C) 2005 by Xilinx, Inc.  All rights reserved.  This
-- text/file contains proprietary, confidential information of Xilinx,
-- Inc., is distributed under license from Xilinx, Inc., and may be used,
-- copied and/or disclosed only pursuant to the terms of a valid license
-- agreement with Xilinx, Inc.  Xilinx hereby grants you a license to use
-- this text/file solely for design, simulation, implementation and
-- creation of design files limited to Xilinx devices or technologies.
-- Use with non-Xilinx devices or technologies is expressly prohibited
-- and immediately terminates your license unless covered by a separate
-- agreement.
--
-- Xilinx is providing this design, code, or information "as is" solely
-- for use in developing programs and solutions for Xilinx devices.  By
-- providing this design, code, or information as one possible
-- implementation of this feature, application or standard, Xilinx is
-- making no representation that this implementation is free from any
-- claims of infringement.  You are responsible for obtaining any rights
-- you may require for your implementation.  Xilinx expressly disclaims
-- any warranty whatsoever with respect to the adequacy of the
-- implementation, including but not limited to warranties of
-- merchantability or fitness for a particular purpose.
--
-- Xilinx products are not intended for use in life support appliances,
-- devices, or systems.  Use in such applications is expressly prohibited.
--
-- Any modifications that are made to the source code are done at the user's
-- sole risk and will be unsupported.
--
-- This copyright and support notice must be retained as part of this
-- text at all times.  (c) Copyright 1995-2005 Xilinx, Inc.  All rights
-- reserved.
-------------------------------------------------------------------
library IEEE;
use IEEE.std_logic_1164.all;
use work.conv_pkg.all;
-- synopsys translate_off
library unisim;
use unisim.vcomponents.all;
-- synopsys translate_on
entity single_reg_w_init is
  generic (
    width: integer := 8;
    init_index: integer := 0;
    init_value: bit_vector := b"0000"
  );
  port (
    i: in std_logic_vector(width - 1 downto 0);
    ce: in std_logic;
    clr: in std_logic;
    clk: in std_logic;
    o: out std_logic_vector(width - 1 downto 0)
  );
end single_reg_w_init;
architecture structural of single_reg_w_init is
  function build_init_const(width: integer;
                            init_index: integer;
                            init_value: bit_vector)
    return std_logic_vector
  is
    variable result: std_logic_vector(width - 1 downto 0);
  begin
    if init_index = 0 then
      result := (others => '0');
    elsif init_index = 1 then
      result := (others => '0');
      result(0) := '1';
    else
      result := to_stdlogicvector(init_value);
    end if;
    return result;
  end;
  component fdre
    port (
      q: out std_ulogic;
      d: in  std_ulogic;
      c: in  std_ulogic;
      ce: in  std_ulogic;
      r: in  std_ulogic
    );
  end component;
  attribute syn_black_box of fdre: component is true;
  attribute fpga_dont_touch of fdre: component is "true";
  component fdse
    port (
      q: out std_ulogic;
      d: in  std_ulogic;
      c: in  std_ulogic;
      ce: in  std_ulogic;
      s: in  std_ulogic
    );
  end component;
  attribute syn_black_box of fdse: component is true;
  attribute fpga_dont_touch of fdse: component is "true";
  constant init_const: std_logic_vector(width - 1 downto 0)
    := build_init_const(width, init_index, init_value);
begin
  fd_prim_array: for index in 0 to width - 1 generate
    bit_is_0: if (init_const(index) = '0') generate
      fdre_comp: fdre
        port map (
          c => clk,
          d => i(index),
          q => o(index),
          ce => ce,
          r => clr
        );
    end generate;
    bit_is_1: if (init_const(index) = '1') generate
      fdse_comp: fdse
        port map (
          c => clk,
          d => i(index),
          q => o(index),
          ce => ce,
          s => clr
        );
    end generate;
  end generate;
end architecture structural;
library IEEE;
use IEEE.std_logic_1164.all;
use work.conv_pkg.all;
-- synopsys translate_off
library unisim;
use unisim.vcomponents.all;
-- synopsys translate_on
entity synth_reg_w_init is
  generic (
    width: integer := 8;
    init_index: integer := 0;
    init_value: bit_vector := b"0000";
    latency: integer := 1
  );
  port (
    i: in std_logic_vector(width - 1 downto 0);
    ce: in std_logic;
    clr: in std_logic;
    clk: in std_logic;
    o: out std_logic_vector(width - 1 downto 0)
  );
end synth_reg_w_init;
architecture structural of synth_reg_w_init is
  component single_reg_w_init
    generic (
      width: integer := 8;
      init_index: integer := 0;
      init_value: bit_vector := b"0000"
    );
    port (
      i: in std_logic_vector(width - 1 downto 0);
      ce: in std_logic;
      clr: in std_logic;
      clk: in std_logic;
      o: out std_logic_vector(width - 1 downto 0)
    );
  end component;
  signal dly_i: std_logic_vector((latency + 1) * width - 1 downto 0);
  signal dly_clr: std_logic;
begin
  latency_eq_0: if (latency = 0) generate
    o <= i;
  end generate;
  latency_gt_0: if (latency >= 1) generate
    dly_i((latency + 1) * width - 1 downto latency * width) <= i
      after 200 ps;
    dly_clr <= clr after 200 ps;
    fd_array: for index in latency downto 1 generate
       reg_comp: single_reg_w_init
          generic map (
            width => width,
            init_index => init_index,
            init_value => init_value
          )
          port map (
            clk => clk,
            i => dly_i((index + 1) * width - 1 downto index * width),
            o => dly_i(index * width - 1 downto (index - 1) * width),
            ce => ce,
            clr => dly_clr
          );
    end generate;
    o <= dly_i(width - 1 downto 0);
  end generate;
end structural;


-------------------------------------------------------------------
-- System Generator version 7.1.01 VHDL source file.
--
-- Copyright(C) 2005 by Xilinx, Inc.  All rights reserved.  This
-- text/file contains proprietary, confidential information of Xilinx,
-- Inc., is distributed under license from Xilinx, Inc., and may be used,
-- copied and/or disclosed only pursuant to the terms of a valid license
-- agreement with Xilinx, Inc.  Xilinx hereby grants you a license to use
-- this text/file solely for design, simulation, implementation and
-- creation of design files limited to Xilinx devices or technologies.
-- Use with non-Xilinx devices or technologies is expressly prohibited
-- and immediately terminates your license unless covered by a separate
-- agreement.
--
-- Xilinx is providing this design, code, or information "as is" solely
-- for use in developing programs and solutions for Xilinx devices.  By
-- providing this design, code, or information as one possible
-- implementation of this feature, application or standard, Xilinx is
-- making no representation that this implementation is free from any
-- claims of infringement.  You are responsible for obtaining any rights
-- you may require for your implementation.  Xilinx expressly disclaims
-- any warranty whatsoever with respect to the adequacy of the
-- implementation, including but not limited to warranties of
-- merchantability or fitness for a particular purpose.
--
-- Xilinx products are not intended for use in life support appliances,
-- devices, or systems.  Use in such applications is expressly prohibited.
--
-- Any modifications that are made to the source code are done at the user's
-- sole risk and will be unsupported.
--
-- This copyright and support notice must be retained as part of this
-- text at all times.  (c) Copyright 1995-2005 Xilinx, Inc.  All rights
-- reserved.
-------------------------------------------------------------------
library IEEE;
use IEEE.std_logic_1164.all;
use work.conv_pkg.all;
use work.clock_pkg.all;
entity xlclkprobe is
  port (clk             : in std_logic;
        clr             : in std_logic;
        ce              : in std_logic;
        fakeOutForXst   : out std_logic);
end xlclkprobe;
architecture behavior of xlclkprobe is
begin
   fakeOutForXst <= '0';
-- synopsys translate_off
   work.clock_pkg.int_clk <= clk;
-- synopsys translate_on
end behavior;


-------------------------------------------------------------------
-- System Generator version 7.1.01 VHDL source file.
--
-- Copyright(C) 2005 by Xilinx, Inc.  All rights reserved.  This
-- text/file contains proprietary, confidential information of Xilinx,
-- Inc., is distributed under license from Xilinx, Inc., and may be used,
-- copied and/or disclosed only pursuant to the terms of a valid license
-- agreement with Xilinx, Inc.  Xilinx hereby grants you a license to use
-- this text/file solely for design, simulation, implementation and
-- creation of design files limited to Xilinx devices or technologies.
-- Use with non-Xilinx devices or technologies is expressly prohibited
-- and immediately terminates your license unless covered by a separate
-- agreement.
--
-- Xilinx is providing this design, code, or information "as is" solely
-- for use in developing programs and solutions for Xilinx devices.  By
-- providing this design, code, or information as one possible
-- implementation of this feature, application or standard, Xilinx is
-- making no representation that this implementation is free from any
-- claims of infringement.  You are responsible for obtaining any rights
-- you may require for your implementation.  Xilinx expressly disclaims
-- any warranty whatsoever with respect to the adequacy of the
-- implementation, including but not limited to warranties of
-- merchantability or fitness for a particular purpose.
--
-- Xilinx products are not intended for use in life support appliances,
-- devices, or systems.  Use in such applications is expressly prohibited.
--
-- Any modifications that are made to the source code are done at the user's
-- sole risk and will be unsupported.
--
-- This copyright and support notice must be retained as part of this
-- text at all times.  (c) Copyright 1995-2005 Xilinx, Inc.  All rights
-- reserved.
-------------------------------------------------------------------
library IEEE;
use IEEE.std_logic_1164.all;
use IEEE.std_logic_arith.all;
use work.conv_pkg.all;
entity xlsl2slv is
  generic (
    dout_width: integer := 1;
    dout_bin_pt: integer := 0;
    dout_arith: integer := xlUnsigned
  );
  port (
    din: in std_logic;
    dout: out std_logic_vector(dout_width - 1 downto 0)
  );
end xlsl2slv;
architecture behavior of xlsl2slv is
begin
    dout(0) <= din;
end behavior;


-------------------------------------------------------------------
-- System Generator version 7.1.01 VHDL source file.
--
-- Copyright(C) 2005 by Xilinx, Inc.  All rights reserved.  This
-- text/file contains proprietary, confidential information of Xilinx,
-- Inc., is distributed under license from Xilinx, Inc., and may be used,
-- copied and/or disclosed only pursuant to the terms of a valid license
-- agreement with Xilinx, Inc.  Xilinx hereby grants you a license to use
-- this text/file solely for design, simulation, implementation and
-- creation of design files limited to Xilinx devices or technologies.
-- Use with non-Xilinx devices or technologies is expressly prohibited
-- and immediately terminates your license unless covered by a separate
-- agreement.
--
-- Xilinx is providing this design, code, or information "as is" solely
-- for use in developing programs and solutions for Xilinx devices.  By
-- providing this design, code, or information as one possible
-- implementation of this feature, application or standard, Xilinx is
-- making no representation that this implementation is free from any
-- claims of infringement.  You are responsible for obtaining any rights
-- you may require for your implementation.  Xilinx expressly disclaims
-- any warranty whatsoever with respect to the adequacy of the
-- implementation, including but not limited to warranties of
-- merchantability or fitness for a particular purpose.
--
-- Xilinx products are not intended for use in life support appliances,
-- devices, or systems.  Use in such applications is expressly prohibited.
--
-- Any modifications that are made to the source code are done at the user's
-- sole risk and will be unsupported.
--
-- This copyright and support notice must be retained as part of this
-- text at all times.  (c) Copyright 1995-2005 Xilinx, Inc.  All rights
-- reserved.
-------------------------------------------------------------------
library IEEE;
use IEEE.std_logic_1164.all;
use IEEE.std_logic_arith.all;
use work.conv_pkg.all;
entity xlslv2sl is
  generic (
    din_width: integer := 1;
    din_bin_pt: integer := 0;
    din_arith: integer := xlUnsigned
  );
  port (
    din: in std_logic_vector(din_width - 1 downto 0);
    dout: out std_logic
  );
end xlslv2sl;
architecture behavior of xlslv2sl is
begin
    dout <= din(0);
end behavior;


-------------------------------------------------------------------
-- System Generator version 7.1.01 VHDL source file.
--
-- Copyright(C) 2005 by Xilinx, Inc.  All rights reserved.  This
-- text/file contains proprietary, confidential information of Xilinx,
-- Inc., is distributed under license from Xilinx, Inc., and may be used,
-- copied and/or disclosed only pursuant to the terms of a valid license
-- agreement with Xilinx, Inc.  Xilinx hereby grants you a license to use
-- this text/file solely for design, simulation, implementation and
-- creation of design files limited to Xilinx devices or technologies.
-- Use with non-Xilinx devices or technologies is expressly prohibited
-- and immediately terminates your license unless covered by a separate
-- agreement.
--
-- Xilinx is providing this design, code, or information "as is" solely
-- for use in developing programs and solutions for Xilinx devices.  By
-- providing this design, code, or information as one possible
-- implementation of this feature, application or standard, Xilinx is
-- making no representation that this implementation is free from any
-- claims of infringement.  You are responsible for obtaining any rights
-- you may require for your implementation.  Xilinx expressly disclaims
-- any warranty whatsoever with respect to the adequacy of the
-- implementation, including but not limited to warranties of
-- merchantability or fitness for a particular purpose.
--
-- Xilinx products are not intended for use in life support appliances,
-- devices, or systems.  Use in such applications is expressly prohibited.
--
-- Any modifications that are made to the source code are done at the user's
-- sole risk and will be unsupported.
--
-- This copyright and support notice must be retained as part of this
-- text at all times.  (c) Copyright 1995-2005 Xilinx, Inc.  All rights
-- reserved.
-------------------------------------------------------------------
library IEEE;
use IEEE.std_logic_1164.all;
use work.conv_pkg.all;
use work.clock_pkg.all;
entity xlslicer is
  generic (
    din_width: integer := 1;
    slice_top: integer := 1;
    slice_bottom: integer := 1
  );
  port (
    din: in std_logic_vector(din_width - 1 downto 0);
    dout: out std_logic_vector(slice_top - slice_bottom downto 0)
  );
end xlslicer;
architecture behavior of xlslicer is
begin
  dout <= din(slice_top downto slice_bottom);
end behavior;


-------------------------------------------------------------------
-- System Generator version 7.1.01 VHDL source file.
--
-- Copyright(C) 2005 by Xilinx, Inc.  All rights reserved.  This
-- text/file contains proprietary, confidential information of Xilinx,
-- Inc., is distributed under license from Xilinx, Inc., and may be used,
-- copied and/or disclosed only pursuant to the terms of a valid license
-- agreement with Xilinx, Inc.  Xilinx hereby grants you a license to use
-- this text/file solely for design, simulation, implementation and
-- creation of design files limited to Xilinx devices or technologies.
-- Use with non-Xilinx devices or technologies is expressly prohibited
-- and immediately terminates your license unless covered by a separate
-- agreement.
--
-- Xilinx is providing this design, code, or information "as is" solely
-- for use in developing programs and solutions for Xilinx devices.  By
-- providing this design, code, or information as one possible
-- implementation of this feature, application or standard, Xilinx is
-- making no representation that this implementation is free from any
-- claims of infringement.  You are responsible for obtaining any rights
-- you may require for your implementation.  Xilinx expressly disclaims
-- any warranty whatsoever with respect to the adequacy of the
-- implementation, including but not limited to warranties of
-- merchantability or fitness for a particular purpose.
--
-- Xilinx products are not intended for use in life support appliances,
-- devices, or systems.  Use in such applications is expressly prohibited.
--
-- Any modifications that are made to the source code are done at the user's
-- sole risk and will be unsupported.
--
-- This copyright and support notice must be retained as part of this
-- text at all times.  (c) Copyright 1995-2005 Xilinx, Inc.  All rights
-- reserved.
-------------------------------------------------------------------
library IEEE;
use IEEE.std_logic_1164.all;
use work.conv_pkg.all;
entity convert_func_call is
    generic (
        din_width    : integer := 16;
        din_bin_pt   : integer := 4;
        din_arith    : integer := xlUnsigned;
        dout_width   : integer := 8;
        dout_bin_pt  : integer := 2;
        dout_arith   : integer := xlUnsigned;
        quantization : integer := xlTruncate;
        overflow     : integer := xlWrap);
    port (
        din : in std_logic_vector (din_width-1 downto 0);
        result : out std_logic_vector (dout_width-1 downto 0));
end convert_func_call;
architecture behavior of convert_func_call is
begin
    result <= convert_type(din, din_width, din_bin_pt, din_arith,
                           dout_width, dout_bin_pt, dout_arith,
                           quantization, overflow);
end behavior;
library IEEE;
use IEEE.std_logic_1164.all;
use work.conv_pkg.all;
entity xlconvert is
    generic (
        din_width    : integer := 16;
        din_bin_pt   : integer := 4;
        din_arith    : integer := xlUnsigned;
        dout_width   : integer := 8;
        dout_bin_pt  : integer := 2;
        dout_arith   : integer := xlUnsigned;
        bool_conversion : integer :=0;
        latency      : integer := 0;
        quantization : integer := xlTruncate;
        overflow     : integer := xlWrap);
    port (
        din : in std_logic_vector (din_width-1 downto 0);
        ce  : in std_logic;
        clr : in std_logic;
        clk : in std_logic;
        dout : out std_logic_vector (dout_width-1 downto 0));
end xlconvert;
architecture behavior of xlconvert is
    component synth_reg
        generic (width       : integer;
                 latency     : integer);
        port (i           : in std_logic_vector(width-1 downto 0);
              ce      : in std_logic;
              clr     : in std_logic;
              clk     : in std_logic;
              o       : out std_logic_vector(width-1 downto 0));
    end component;
    component convert_func_call
        generic (
            din_width    : integer := 16;
            din_bin_pt   : integer := 4;
            din_arith    : integer := xlUnsigned;
            dout_width   : integer := 8;
            dout_bin_pt  : integer := 2;
            dout_arith   : integer := xlUnsigned;
            quantization : integer := xlTruncate;
            overflow     : integer := xlWrap);
        port (
            din : in std_logic_vector (din_width-1 downto 0);
            result : out std_logic_vector (dout_width-1 downto 0));
    end component;
    -- synopsys translate_off
    signal real_din, real_dout : real;
    -- synopsys translate_on
    signal result : std_logic_vector(dout_width-1 downto 0);
begin
    -- synopsys translate_off
    -- synopsys translate_on
    bool_conversion_generate : if (bool_conversion = 1)
    generate
      result <= din;
    end generate;
    std_conversion_generate : if (bool_conversion = 0)
    generate
      convert : convert_func_call
        generic map (
          din_width   => din_width,
          din_bin_pt  => din_bin_pt,
          din_arith   => din_arith,
          dout_width  => dout_width,
          dout_bin_pt => dout_bin_pt,
          dout_arith  => dout_arith,
          quantization => quantization,
          overflow     => overflow)
        port map (
          din => din,
          result => result);
    end generate;
    latency_test : if (latency > 0)
    generate
        reg : synth_reg
            generic map ( width => dout_width,
                          latency => latency)
            port map (i => result,
                      ce => ce,
                      clr => clr,
                      clk => clk,
                      o => dout);
    end generate;
    latency0 : if (latency = 0)
    generate
        dout <= result;
    end generate latency0;
end  behavior;


-------------------------------------------------------------------
-- System Generator version 7.1.01 VHDL source file.
--
-- Copyright(C) 2005 by Xilinx, Inc.  All rights reserved.  This
-- text/file contains proprietary, confidential information of Xilinx,
-- Inc., is distributed under license from Xilinx, Inc., and may be used,
-- copied and/or disclosed only pursuant to the terms of a valid license
-- agreement with Xilinx, Inc.  Xilinx hereby grants you a license to use
-- this text/file solely for design, simulation, implementation and
-- creation of design files limited to Xilinx devices or technologies.
-- Use with non-Xilinx devices or technologies is expressly prohibited
-- and immediately terminates your license unless covered by a separate
-- agreement.
--
-- Xilinx is providing this design, code, or information "as is" solely
-- for use in developing programs and solutions for Xilinx devices.  By
-- providing this design, code, or information as one possible
-- implementation of this feature, application or standard, Xilinx is
-- making no representation that this implementation is free from any
-- claims of infringement.  You are responsible for obtaining any rights
-- you may require for your implementation.  Xilinx expressly disclaims
-- any warranty whatsoever with respect to the adequacy of the
-- implementation, including but not limited to warranties of
-- merchantability or fitness for a particular purpose.
--
-- Xilinx products are not intended for use in life support appliances,
-- devices, or systems.  Use in such applications is expressly prohibited.
--
-- Any modifications that are made to the source code are done at the user's
-- sole risk and will be unsupported.
--
-- This copyright and support notice must be retained as part of this
-- text at all times.  (c) Copyright 1995-2005 Xilinx, Inc.  All rights
-- reserved.
-------------------------------------------------------------------
library IEEE;
use IEEE.std_logic_1164.all;
use work.conv_pkg.all;
entity xldelay is
   generic(d_width    : integer := 5;
           d_bin_pt   : integer := 2;
           d_arith    : integer := xlUnsigned;
           q_width    : integer := 5;
           q_bin_pt   : integer := 2;
           q_arith    : integer := xlUnsigned;
           rst_width  : integer := 1;
           rst_bin_pt : integer := 0;
           en_width   : integer := 5;
           en_bin_pt  : integer := 2;
           en_arith   : integer := xlUnsigned;
           rst_arith  : integer := xlUnsigned;
           latency    : integer := 10;
           reg_retiming: boolean := false);
   port(d       : in std_logic_vector (d_width-1 downto 0);
        ce      : in std_logic;
        clr     : in std_logic;
        clk     : in std_logic;
        rst     : in std_logic_vector (rst_width-1 downto 0);
        en      : in std_logic_vector (en_width-1 downto 0);
        q       : out std_logic_vector (q_width-1 downto 0));
end xldelay;
architecture behavior of xldelay is
   component synth_reg
      generic (width       : integer;
               latency     : integer);
      port (i           : in std_logic_vector(width-1 downto 0);
            ce      : in std_logic;
            clr     : in std_logic;
            clk     : in std_logic;
            o       : out std_logic_vector(width-1 downto 0));
   end component;
   component synth_reg_reg
      generic (width       : integer;
               latency     : integer);
      port (i           : in std_logic_vector(width-1 downto 0);
            ce      : in std_logic;
            clr     : in std_logic;
            clk     : in std_logic;
            o       : out std_logic_vector(width-1 downto 0));
   end component;
   signal internal_ce  : std_logic;
   signal internal_clr : std_logic;
begin
   internal_ce  <= ce and (en(0));
   internal_clr <= (clr or (rst(0))) and ce;
   srl_delay: if (not reg_retiming) or (latency<1) generate
     synth_reg_srl_inst : synth_reg
       generic map (
         width   => d_width,
         latency => latency)
       port map (
         i   => d,
         ce  => internal_ce,
         clr => internal_clr,
         clk => clk,
         o   => q);
   end generate srl_delay;
   reg_delay: if reg_retiming and (latency>=1) generate
     synth_reg_reg_inst : synth_reg_reg
       generic map (
         width   => d_width,
         latency => latency)
       port map (
         i   => d,
         ce  => internal_ce,
         clr => internal_clr,
         clk => clk,
         o   => q);
   end generate reg_delay;
end architecture behavior;


-------------------------------------------------------------------
-- System Generator version 7.1.01 VHDL source file.
--
-- Copyright(C) 2005 by Xilinx, Inc.  All rights reserved.  This
-- text/file contains proprietary, confidential information of Xilinx,
-- Inc., is distributed under license from Xilinx, Inc., and may be used,
-- copied and/or disclosed only pursuant to the terms of a valid license
-- agreement with Xilinx, Inc.  Xilinx hereby grants you a license to use
-- this text/file solely for design, simulation, implementation and
-- creation of design files limited to Xilinx devices or technologies.
-- Use with non-Xilinx devices or technologies is expressly prohibited
-- and immediately terminates your license unless covered by a separate
-- agreement.
--
-- Xilinx is providing this design, code, or information "as is" solely
-- for use in developing programs and solutions for Xilinx devices.  By
-- providing this design, code, or information as one possible
-- implementation of this feature, application or standard, Xilinx is
-- making no representation that this implementation is free from any
-- claims of infringement.  You are responsible for obtaining any rights
-- you may require for your implementation.  Xilinx expressly disclaims
-- any warranty whatsoever with respect to the adequacy of the
-- implementation, including but not limited to warranties of
-- merchantability or fitness for a particular purpose.
--
-- Xilinx products are not intended for use in life support appliances,
-- devices, or systems.  Use in such applications is expressly prohibited.
--
-- Any modifications that are made to the source code are done at the user's
-- sole risk and will be unsupported.
--
-- This copyright and support notice must be retained as part of this
-- text at all times.  (c) Copyright 1995-2005 Xilinx, Inc.  All rights
-- reserved.
-------------------------------------------------------------------
library IEEE;
use IEEE.std_logic_1164.all;
use IEEE.std_logic_unsigned.all;
use work.conv_pkg.all;
entity raminfr is
  generic (width : integer := 8);
  port (clk  : in std_logic;
        we   : in std_logic;
        a    : in std_logic_vector(3 downto 0);
        dpra : in std_logic_vector(3 downto 0);
        di   : in std_logic_vector(width-1 downto 0);
        spo  : out std_logic_vector(width-1 downto 0);
        dpo  : out std_logic_vector(width-1 downto 0));
end raminfr;
architecture syn of raminfr is
  type ram_type is array (15 downto 0)
    of std_logic_vector(width-1 downto 0);
  signal RAM : ram_type;
begin
  process(clk)
  begin
    if (clk'event and clk = '1') then
      if (we = '1') then
        RAM(conv_integer(a)) <= di;
      end if;
    end if;
  end process;
  spo <= RAM(conv_integer(a));
  dpo <= RAM(conv_integer(dpra));
end syn;
library IEEE;
use IEEE.std_logic_1164.all;
use IEEE.numeric_std.all;
use work.conv_pkg.all;
entity sync_fifo is
  generic (din_width   : integer := 8;
           din_bin_pt  : integer := 2;
           din_arith   : integer := xlSigned;
           dout_width  : integer := 18;
           dout_bin_pt : integer := 8;
           dout_arith  : integer := xlSigned;
           depth       : integer := 3);
  port (din      : in std_logic_vector (din_width-1 downto 0);
        write_ce : in std_logic;
        read_ce  : in std_logic;
        clr      : in std_logic;
        clk      : in std_logic;
        dout     : out std_logic_vector (dout_width-1 downto 0));
end sync_fifo;
architecture behavior of sync_fifo is
  constant depth_minus_1 : unsigned(2 downto 0) := std_logic_vector_to_unsigned(
    integer_to_std_logic_vector (depth-1,3,xlUnsigned));

  component raminfr is
    generic (width : integer := 8);
    port (clk  : in std_logic;
          we   : in std_logic;
          a    : in std_logic_vector(3 downto 0);
          dpra : in std_logic_vector(3 downto 0);
          di   : in std_logic_vector(width-1 downto 0);
          spo  : out std_logic_vector(width-1 downto 0);
          dpo  : out std_logic_vector(width-1 downto 0));
  end component;

  signal not_empty : std_logic := '0';
  signal write_pos : unsigned(2 downto 0) := "000";
  signal read_pos  : unsigned(2 downto 0) := "000";
  signal ram_data  : std_logic_vector(dout_width-1 downto 0) := (others => '0');
  signal write_addr : std_logic_vector(3 downto 0) := (others => '0');
  signal read_addr  : std_logic_vector(3 downto 0) := (others => '0');
begin
  write_addr(2 downto 0) <= unsigned_to_std_logic_vector(write_pos);
  write_addr(3) <= '0';
  read_addr(2 downto 0) <= unsigned_to_std_logic_vector(read_pos);
  read_addr(3) <= '0';

  distributed_ram : raminfr
    generic map (width => dout_width)
    port map (clk  => clk,
              we   => write_ce,
              a    => write_addr,
              dpra => read_addr,
              di   => din,
              spo  => open,
              dpo  => ram_data);
  process (clr, clk)
  begin
    if (rising_edge(clk)) then
      if (clr = '1') then
        write_pos <= (others => '0');
        read_pos <= (others => '0');
        not_empty <= '0';
        dout <= (others => '0');
      else
        if (write_ce = '1') then
          not_empty <= '1';
          if write_pos = depth_minus_1 then
            write_pos <= "000";
          else
            write_pos <= write_pos + 1;
          end if;
        end if;
        if read_ce = '1' then
          if not_empty = '1' then
            if read_pos = depth_minus_1 then
              read_pos <= "000";
            else
              read_pos <= read_pos + 1;
            end if;
          end if;
          dout <= ram_data;
        end if;
      end if;
    end if;
  end process;
end behavior;


-------------------------------------------------------------------
-- System Generator version 7.1.01 VHDL source file.
--
-- Copyright(C) 2005 by Xilinx, Inc.  All rights reserved.  This
-- text/file contains proprietary, confidential information of Xilinx,
-- Inc., is distributed under license from Xilinx, Inc., and may be used,
-- copied and/or disclosed only pursuant to the terms of a valid license
-- agreement with Xilinx, Inc.  Xilinx hereby grants you a license to use
-- this text/file solely for design, simulation, implementation and
-- creation of design files limited to Xilinx devices or technologies.
-- Use with non-Xilinx devices or technologies is expressly prohibited
-- and immediately terminates your license unless covered by a separate
-- agreement.
--
-- Xilinx is providing this design, code, or information "as is" solely
-- for use in developing programs and solutions for Xilinx devices.  By
-- providing this design, code, or information as one possible
-- implementation of this feature, application or standard, Xilinx is
-- making no representation that this implementation is free from any
-- claims of infringement.  You are responsible for obtaining any rights
-- you may require for your implementation.  Xilinx expressly disclaims
-- any warranty whatsoever with respect to the adequacy of the
-- implementation, including but not limited to warranties of
-- merchantability or fitness for a particular purpose.
--
-- Xilinx products are not intended for use in life support appliances,
-- devices, or systems.  Use in such applications is expressly prohibited.
--
-- Any modifications that are made to the source code are done at the user's
-- sole risk and will be unsupported.
--
-- This copyright and support notice must be retained as part of this
-- text at all times.  (c) Copyright 1995-2005 Xilinx, Inc.  All rights
-- reserved.
-------------------------------------------------------------------
library IEEE;
-- synopsys translate_off
library XilinxCoreLib;
-- synopsys translate_on
use IEEE.std_logic_1164.all;
use work.conv_pkg.all;
-- synopsys translate_off
library unisim;
use unisim.vcomponents.all;
-- synopsys translate_on
entity bandpass_filter_hw_fir is
  generic (
    core_name0: string := "";
    din0_width: integer := 8;
    din0_bin_pt: integer := 2;
    din0_arith: integer := xlSigned;
    dout0_width: integer := 18;
    dout0_bin_pt: integer := 8;
    dout0_arith: integer := xlSigned;
    vin_width: integer := 1;
    vin_bin_pt: integer := 0;
    vin_arith: integer := xlUnsigned;
    vout_width: integer := 1;
    vout_bin_pt: integer := 0;
    vout_arith: integer := xlUnsigned;
    c_data_width: integer := 8;
    c_result_width: integer := 18;
    c_coeff_width: integer := 8;
    c_taps: integer := 2;
    c_response: integer := 1;
    c_data_type: integer := 0;
    c_coeff_type: integer := 8;
    c_channels: integer := 1;
    c_filter_type: integer := 0;
    c_saturate: integer := 0;
    c_has_sel_o: integer := 0;
    c_has_sel_i: integer := 0;
                -- synopsys translate_off
    c_mem_init_file: string := "null.mif";
                -- synopsys translate_on
    uid: integer := 0;
    c_zpf: integer := 1;
    c_polyphase_factor: integer := 1;
    c_reg_output: integer := 1;
    c_baat: integer := 8;
    c_use_model_func: integer := 0;
    c_latency: integer := 6;
    core_clk_at_sys_rate: integer := 0;
    clks_per_sample: integer := 1;
    latency: integer := 1;
    core_latency: integer := 1;
    interpolating: integer := 1;
    extra_registers: integer := 0
  );
  port (
    din0: in std_logic_vector(din0_width - 1 downto 0);
    vin: in std_logic_vector(0 downto 0) := "1";
    sample_in_ce: in std_logic;
    sample_in_clr: in std_logic;
    sample_in_clk: in std_logic;
    core_ce: in std_logic;
    core_clr: in std_logic;
    core_clk: in std_logic;
    sample_out_ce: in std_logic;
    sample_out_clr: in std_logic;
    sample_out_clk: in std_logic;
    dout0: out std_logic_vector(dout0_width - 1 downto 0);
    vout: out std_logic_vector(vout_width - 1 downto 0)
  );
end bandpass_filter_hw_fir;
architecture behavior of bandpass_filter_hw_fir is
  component synth_reg
    generic (
      width: integer := 16;
      latency: integer := 5
    );
    port (
      i: in std_logic_vector(width - 1 downto 0);
      ce: in std_logic;
      clr: in std_logic;
      clk: in std_logic;
      o: out std_logic_vector(width - 1 downto 0)
    );
  end component;
  component synth_reg_w_init
    generic (
      width: integer := 16;
      init_index: integer := 0;
      latency: integer := 5
    );
    port (
      i: in std_logic_vector(width - 1 downto 0);
      ce: in std_logic;
      clr: in std_logic;
      clk: in std_logic;
      o: out std_logic_vector(width - 1 downto 0)
    );
  end component;
  component fds
    port (
      q: out std_ulogic;
      d: in std_ulogic;
      c: in std_ulogic;
      s: in std_ulogic
    );
  end component;
  attribute syn_black_box of fds: component is true;
  attribute fpga_dont_touch of fds: component is "true";
  component sync_fifo
    generic (
      din_width: integer := 8;
      din_bin_pt: integer := 2;
      din_arith: integer := xlSigned;
      dout_width: integer := 18;
      dout_bin_pt: integer := 8;
      dout_arith: integer := xlSigned;
      depth: integer := 3
    );
    port (
      din: in std_logic_vector(din_width - 1 downto 0);
      write_ce: in std_logic;
      read_ce: in std_logic;
      clr: in std_logic;
      clk: in std_logic;
      dout: out std_logic_vector(dout_width - 1 downto 0)
    );
  end component;
  signal nd: std_logic;
  signal rfd: std_logic;
  signal core_rdy: std_logic;
  signal registered_rdy: std_logic;
  signal sampled_dout0: std_logic_vector(c_result_width-1 downto 0) :=
    (others => '0');
  signal raw_dout0: std_logic_vector(c_result_width - 1 downto 0);
  signal core_dout0: std_logic_vector(c_result_width - 1 downto 0);
  signal registered_dout0: std_logic_vector(c_result_width - 1 downto 0) :=
    (others => '0');
  signal del_sample_in_ce: std_logic;
  signal clr_pulse, fifo_clr: std_logic;

  -- synopsys translate_off
  signal real_din0, real_core_dout0, real_sampled_dout0,
    real_sampled_dout0_dly, real_dout0: real;
  -- synopsys translate_on
  component distributed_arithmetic_fir_filter_virtex2p_9_0_398549419effdecb
    port (
      nd: in std_logic;
      rdy: out std_logic;
      clk: in std_logic;
      rfd: out std_logic;
      din: in std_logic_vector(c_data_width - 1 downto 0);
      dout: out std_logic_vector(c_result_width - 1 downto 0)
    );
  end component;
  attribute syn_black_box of distributed_arithmetic_fir_filter_virtex2p_9_0_398549419effdecb: component is true;
  attribute fpga_dont_touch of distributed_arithmetic_fir_filter_virtex2p_9_0_398549419effdecb: component is "true";
begin
  -- synopsys translate_off
  -- synopsys translate_on
  sample_in_ce_reg: fds
    port map (
      q => del_sample_in_ce,
      d => sample_in_ce,
      c => core_clk,
      s => core_clr
    );
  nd <= vin(0) and del_sample_in_ce;
  comp0: if (not simulating and
             (core_name0 = "distributed_arithmetic_fir_filter_virtex2p_9_0_398549419effdecb")) generate
    core_instance0: distributed_arithmetic_fir_filter_virtex2p_9_0_398549419effdecb
      port map (
        nd => nd,
        rdy => core_rdy,
        clk => core_clk,
        rfd => rfd,
        din => din0,
        dout => core_dout0
      );
  end generate;
-- synopsys translate_off
  comp1: if (simulating and
             (core_name0 = "distributed_arithmetic_fir_filter_virtex2p_9_0_398549419effdecb")) generate
    core_instance1: entity XilinxCoreLib.c_da_fir_v9_0(behavioral)
      generic map (
        c_baat => c_baat,
        c_has_sin_f => 0,
        c_channels => c_channels,
        c_has_sel_o => c_has_sel_o,
        c_reload_delay => 0,
        c_reload_mem_type => 1,
        c_filter_type => c_filter_type,
        c_has_sel_i => c_has_sel_i,
        c_shape => 0,
        c_coeff_type => c_coeff_type,
        c_taps => c_taps,
        c_has_sout_r => 0,
        c_zpf => c_zpf,
        c_polyphase_factor => c_polyphase_factor,
        c_data_width => c_data_width,
        c_has_sout_f => 0,
        c_optimize => 1,
        c_use_model_func => c_use_model_func,
        c_data_type => c_data_type,
        c_latency => c_latency,
        c_coeff_width => c_coeff_width,
        c_has_reset => 0,
        c_reload => 0,
        c_result_width => c_result_width,
        c_saturate => c_saturate,
        c_mem_init_file => c_mem_init_file,
        c_reg_output => c_reg_output,
        c_has_sin_r => 0,
        c_enable_rlocs => 0,
        c_response => c_response
      )
      port map (
        nd => nd,
        rdy => core_rdy,
        clk => core_clk,
        rfd => rfd,
        din => din0,
        dout => core_dout0
      );
  end generate;
-- synopsys translate_on
  reg_core_output: process (core_clk, core_clr)
  begin
    if core_clr = '1' then
      registered_dout0 <= (others => '0');
    elsif core_clk'event and core_clk = '1' then
      if core_rdy = '1' then
        registered_dout0 <= core_dout0;
      end if;
      registered_rdy <= core_rdy;
    end if;
  end process;
  valid_pipe: synth_reg_w_init
    generic map (
      width => 1,
      init_index => 0,
      latency => latency
    )
    port map (
      i => vin,
      ce => sample_out_ce,
      clr => sample_out_clr,
      clk => core_clk,
      o => vout
    );
  polyphase_eq_1: if not((interpolating = 1) and (c_polyphase_factor > 1))
  generate
    sample_output: process (core_clk)
    begin
      if core_clk'event and core_clk = '1' then
        if sample_out_ce = '1' then
          sampled_dout0 <= registered_dout0;
        end if;
      end if;
    end process;
  end generate;
  polyphase_gt_1: if (interpolating = 1) and (c_polyphase_factor > 1)
  generate
   fifo_clr_ff: fds
    port map (
      q => clr_pulse,
      d => '0',
      c => core_clk,
      s => core_clr
    );
    fifo_clr <= clr_pulse or sample_out_clr;

    sync_fifo_comp: sync_fifo
      generic map (
        din_width => c_result_width,
        din_bin_pt => dout0_bin_pt,
        din_arith => dout0_arith,
        dout_width => c_result_width,
        dout_bin_pt => dout0_bin_pt,
        depth => c_polyphase_factor
      )
      port map (
        din => registered_dout0,
        write_ce => registered_rdy,
        read_ce => sample_out_ce,
        clr => fifo_clr,
        clk => core_clk,
        dout => sampled_dout0
      );
  end generate;
  latency_test: if (extra_registers > 0)
  generate
    reg: synth_reg
      generic map (
        width => c_result_width,
        latency => extra_registers
      )
      port map (
        i => sampled_dout0,
        ce => sample_out_ce,
        clr => sample_out_clr,
        clk => core_clk,
        o => raw_dout0
      );
  end generate;
  latency0: if ((latency = 0) or (extra_registers = 0))
  generate
    raw_dout0 <= sampled_dout0;
  end generate;
  sign_extend: process (raw_dout0)
  begin
    if dout0_arith = xlUnsigned then
      dout0 <= zero_ext(raw_dout0, dout0_width);
    else
      dout0 <= sign_ext(raw_dout0, dout0_width);
    end if;
  end process;
end architecture behavior;


-------------------------------------------------------------------
-- System Generator version 7.1.01 VHDL source file.
--
-- Copyright(C) 2005 by Xilinx, Inc.  All rights reserved.  This
-- text/file contains proprietary, confidential information of Xilinx,
-- Inc., is distributed under license from Xilinx, Inc., and may be used,
-- copied and/or disclosed only pursuant to the terms of a valid license
-- agreement with Xilinx, Inc.  Xilinx hereby grants you a license to use
-- this text/file solely for design, simulation, implementation and
-- creation of design files limited to Xilinx devices or technologies.
-- Use with non-Xilinx devices or technologies is expressly prohibited
-- and immediately terminates your license unless covered by a separate
-- agreement.
--
-- Xilinx is providing this design, code, or information "as is" solely
-- for use in developing programs and solutions for Xilinx devices.  By
-- providing this design, code, or information as one possible
-- implementation of this feature, application or standard, Xilinx is
-- making no representation that this implementation is free from any
-- claims of infringement.  You are responsible for obtaining any rights
-- you may require for your implementation.  Xilinx expressly disclaims
-- any warranty whatsoever with respect to the adequacy of the
-- implementation, including but not limited to warranties of
-- merchantability or fitness for a particular purpose.
--
-- Xilinx products are not intended for use in life support appliances,
-- devices, or systems.  Use in such applications is expressly prohibited.
--
-- Any modifications that are made to the source code are done at the users
-- sole risk and will be unsupported.
--
-- This copyright and support notice must be retained as part of this
-- text at all times.  (c) Copyright 1995-2005 Xilinx, Inc. 
-- All rights reserved.
--------------------------------------------------------------------

library IEEE;
use IEEE.std_logic_1164.all;
use work.conv_pkg.all;
use work.clock_pkg.all;

-- Generated from Simulink block "bandpass_filter_hw"

entity bandpass_filter_hw is
  port (
    ce_9_sg: in std_logic;
    ce_sg: in std_logic;
    clk_9_sg: in std_logic;
    clk_sg: in std_logic;
    gateway_in: in std_logic_vector(7 downto 0);
    gateway_out: out std_logic_vector(7 downto 0)
  );
end bandpass_filter_hw;

architecture structural of bandpass_filter_hw is
  signal ce_9_sg_x_0: std_logic;
  signal ce_sg_x_0: std_logic;
  signal clk_9_sg_x_0: std_logic;
  signal clk_sg_x_0: std_logic;
  signal convert_dout: std_logic_vector(7 downto 0);
  signal delay_q: std_logic_vector(7 downto 0);
  signal fir_dout0: std_logic_vector(21 downto 0);
  signal gateway_in_x_0: std_logic_vector(7 downto 0);
  signal sl2v_0_dout: std_logic_vector(0 downto 0);
  signal sl2v_dout: std_logic_vector(0 downto 0);

begin
  ce_9_sg_x_0 <= ce_9_sg;
  ce_sg_x_0 <= ce_sg;
  clk_9_sg_x_0 <= clk_9_sg;
  clk_sg_x_0 <= clk_sg;
  gateway_in_x_0 <= gateway_in;
  gateway_out <= delay_q;

  convert: entity work.xlconvert
    generic map (
      din_width => 22,
      din_arith => xlSigned,
      din_bin_pt => 17,
      dout_width => 8,
      dout_arith => xlSigned,
      dout_bin_pt => 6,
      bool_conversion => 0,
      latency => 0,
      overflow => xlWrap,
      quantization => xlTruncate
    )
    port map (
      ce => '0',
      clk => '0',
      clr => '0',
      din => fir_dout0,
      dout => convert_dout
    );
  delay: entity work.xldelay
    generic map (
      d_width => 8,
      d_arith => xlSigned,
      d_bin_pt => 6,
      en_width => 1,
      en_arith => xlUnsigned,
      en_bin_pt => 0,
      q_width => 8,
      q_arith => xlSigned,
      q_bin_pt => 6,
      rst_width => 1,
      rst_arith => xlUnsigned,
      rst_bin_pt => 0,
      latency => 1,
      reg_retiming => false
    )
    port map (
      ce => ce_9_sg_x_0,
      clk => clk_9_sg_x_0,
      clr => '0',
      d => convert_dout,
      en => sl2v_dout,
      rst => sl2v_0_dout,
      q => delay_q
    );
  fir: entity work.bandpass_filter_hw_fir
    generic map (
-- synopsys translate_off
      c_mem_init_file => "bandpass_filter_hw_FIR.mif",
-- synopsys translate_on
      din0_width => 8,
      din0_arith => xlSigned,
      din0_bin_pt => 6,
      dout0_width => 22,
      dout0_arith => xlSigned,
      dout0_bin_pt => 17,
      core_name0 => "distributed_arithmetic_fir_filter_virtex2p_9_0_398549419effdecb",
      c_baat => 1,
      c_channels => 1,
      c_coeff_type => 0,
      c_coeff_width => 12,
      c_data_type => 0,
      c_data_width => 8,
      c_filter_type => 0,
      c_has_sel_i => 0,
      c_has_sel_o => 0,
      c_latency => 17,
      c_polyphase_factor => 1,
      c_reg_output => 0,
      c_response => 0,
      c_result_width => 22,
      c_saturate => 0,
      c_taps => 92,
      c_use_model_func => 0,
      c_zpf => 1,
      clks_per_sample => 9,
      core_clk_at_sys_rate => 1,
      core_latency => 4,
      extra_registers => 11,
      interpolating => 0,
      latency => 14
    )
    port map (
      core_ce => ce_sg_x_0,
      core_clk => clk_sg_x_0,
      core_clr => '0',
      din0 => gateway_in_x_0,
      sample_in_ce => ce_9_sg_x_0,
      sample_in_clk => clk_9_sg_x_0,
      sample_in_clr => '0',
      sample_out_ce => ce_9_sg_x_0,
      sample_out_clk => clk_9_sg_x_0,
      sample_out_clr => '0',
      dout0 => fir_dout0
    );
  sl2v: entity work.xlsl2slv
    generic map (
      dout_width => 1,
      dout_arith => xlUnsigned,
      dout_bin_pt => 0
    )
    port map (
      din => '1',
      dout => sl2v_dout
    );
  sl2v_0: entity work.xlsl2slv
    generic map (
      dout_width => 1,
      dout_arith => xlUnsigned,
      dout_bin_pt => 0
    )
    port map (
      din => '0',
      dout => sl2v_0_dout
    );
end structural;

